ecosound.detection package
==========================

Submodules
----------

ecosound.detection.blob\_detector module
----------------------------------------

.. automodule:: ecosound.detection.blob_detector
   :members:
   :undoc-members:
   :show-inheritance:

ecosound.detection.detector\_builder module
-------------------------------------------

.. automodule:: ecosound.detection.detector_builder
   :members:
   :undoc-members:
   :show-inheritance:

ecosound.detection.detector\_template module
--------------------------------------------

.. automodule:: ecosound.detection.detector_template
   :members:
   :undoc-members:
   :show-inheritance:

ecosound.detection.kurtosis\_detector module
--------------------------------------------

.. automodule:: ecosound.detection.kurtosis_detector
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ecosound.detection
   :members:
   :undoc-members:
   :show-inheritance:
